@@ -30,6 +30,14 @@ Philippe "BooK" Bruhat.
 
 Introduced in version 0.89, published on August 28, 2006.
 
+Further updates:
+
+=over 4
+
+=item * version 0.90, published on September 4, 2006
+
+=back
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -252,6 +260,7 @@ ANAGHAKK
 ANARION
 ANATRA
 ANBON
+ANBU
 ANDALE
 ANDERS
 ANDK
@@ -526,6 +535,7 @@ BEPPU
 BERIKV
 BEROV
 BERRY
+BERT
 BETH
 BETTELLI
 BETUL
@@ -948,6 +958,7 @@ COLINK
 COLINM
 COLINO
 COLLINS
+COLMODE
 COMAND
 CONTEB
 CONVERTER
@@ -1222,6 +1233,7 @@ DGREGORY
 DGRIS
 DGSCOPE
 DGUY
+DHA
 DHABLE
 DHAGAN
 DHAGEMAN
@@ -1679,6 +1691,7 @@ FREESIDE
 FRETT
 FREUND
 FRIDA
+FRIED
 FRIEDBERG
 FRIEDO
 FRIGHETTI
@@ -2127,6 +2140,7 @@ ISAACSON
 ISABELLE
 ISHIGAKI
 ISLUE
+ISOYA
 ISTEEL
 ISTERIN
 ITGURU
@@ -2384,6 +2398,7 @@ JIMT
 JIMW
 JINKEE
 JIRO
+JIRWIN
 JJARVINEN
 JJDG
 JJGREEN
@@ -3175,6 +3190,7 @@ MBLYTHE
 MBOECK
 MBRECH
 MBSTE
+MBURNS
 MCAFEE
 MCANTONI
 MCARR
@@ -4038,6 +4054,7 @@ RAM
 RAMAN
 RAMBALDI
 RAMESH
+RAMGOPAL
 RAMKI
 RANA
 RANDERSON
@@ -4461,6 +4478,7 @@ SELKOVJR
 SEMANTICO
 SEMM
 SEN
+SENGER
 SENSEI
 SEPH
 SER
@@ -4906,6 +4924,7 @@ THARDISON
 THARSCH
 THARTMAN
 THEDEVIL
+THHAMON
 THILO
 THINC
 THINCH
@@ -5204,6 +5223,7 @@ WEZ
 WFRERICHS
 WGDAVIS
 WHAMMO
+WHITEB
 WHITEOWL
 WHIZDOG
 WHOELSE
@@ -5362,6 +5382,7 @@ ZERODOGG
 ZETA
 ZEV
 ZEYA
+ZGH
 ZHANGXIN
 ZHIRSCH
 ZHOUXIN
